@@ -23,14 +23,11 @@ class TestClasses( TestCase ):
     
     def test_scp_plotter( self ):
 
-        scp_plotter()
+        self.plotter = scp_plotter()
 
         assert 1
-    
-    #def test_status_plotter( self ):
 
-    #from domauto.status_plotter import status_plotter
-    
-    #   mystatus_plotter = status_plotter()
-    #   assert 1
-    
+    def make_scp_plot( self ):
+        self.plotter.plot( 'KM3NeT_00000043', 4300, 4302 )
+
+        assert 1
